// Copyright 2004-2005 Castle Project - http://www.castleproject.org/
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
//     http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

namespace Demo.ORM
{
	using System;

	using NUnit.Framework;

	using Castle.ActiveRecord;
	using Demo.ORM.Model;


	[TestFixture]
	public class TransactionTestCase : AbstractActiveRecordTest
	{
		[Test]
		public void OneLevelTransaction()
		{
			Post.DeleteAll();
			Blog.DeleteAll();

			BlogService service = (BlogService) container[ typeof(BlogService) ];

			service.Create( "name1", "author1" );
			service.Create( "name2", "author2" );
			service.Create( "name3", "author3" );

			Assert.AreEqual( 3, Blog.FindAll().Length );
		}

		[Test]
		public void DicardingChanges()
		{
			Post.DeleteAll();
			Blog.DeleteAll();

			SessionScope scope = new SessionScope();
			
			Blog.FindAll(); // side effects only

			BlogService service = (BlogService) container[ typeof(BlogService) ];
			Blog blog = service.Create( "name", "author" );
			
			Assert.AreEqual( 1, Blog.FindAll().Length );

			blog.Name = "joe developer";

			scope.Dispose(true);

			Assert.AreEqual( "name", Blog.FindAll()[0].Name );
		}

	
		
		
	}
}
