// Copyright 2004-2005 Castle Project - http://www.castleproject.org/
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
//     http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

namespace QPG.Demo.Services {
	using System;
	using System.Collections;
	//using System.Threading;


	using Castle.Model;
	using QPG.Interface;
	using QPG.Utility;
	using QPG;
	
	public class EmailSender : IService,IStartable {
		private bool _Started = false;
		private bool _Stopped = false;


		private System.Collections.Queue _queue =  System.Collections.Queue.Synchronized(new Queue());
		
		private string _serviceName="qpg.email_sender";
		private BroadCastEventWrapper wrapper=null;
		private System.Timers.Timer _timer;
		private IMessageQueue _mq;
		
		public EmailSender() {
			_mq=SimpleContainer.MessageQueue;
			
			_timer=new System.Timers.Timer(1000);
			_timer.Elapsed+=new System.Timers.ElapsedEventHandler(timer_Elapsed);

		}
		
		public void attach(BroadCastEventHandler func) {
			if(wrapper==null){
				wrapper=new BroadCastEventWrapper();
				wrapper.OnLocalBroadCast += new BroadCastEventHandler(func);
				_mq.OnBroadCast+=new BroadCastEventHandler(wrapper.BroadCasting);
			}
		}

		
		public void detach() {
			_mq.OnBroadCast-=new BroadCastEventHandler(wrapper.BroadCasting);
			
		}
		
		
		public string ServiceName {
			get{return _serviceName;}
		}

		public virtual void Start() {
			if(_Started==true) return;
			SimpleContainer.SysLogger.DEBUG("email_sender Started");
			_timer.Enabled=true;
			_Started=true;
			attach(new QPG.Interface.BroadCastEventHandler(handle));
		}

		public virtual void Stop() {
			SimpleContainer.SysLogger.DEBUG("email_sender Stopped");
			_Stopped =  true;
			_timer.Enabled=false;
			detach();
		}
		public virtual DTO handle(DTO data) {
			_queue.Enqueue(data);
			DTO rt=new DTO(data);
			rt.setOutputData(new Parameter[]{new Parameter("Msg","Put msg to queue-->"+data.RequestArgs[0].Value.ToString())},null);
			return rt;
		}
		protected virtual bool send(ParametersHelper ph) {
			bool rt=true;
			try{
				// real sent by SMTP......
			}
			catch{rt=false;}
			return rt;
		}

		private void getRequest() {
			DTO d=_mq.receieveRequestFromQueue(ServiceName);
			if(d!=null) {
				d=handle(d);// ûж壬ôʲôֻǷһ֪ͨÿͻ˵ȴ
				_mq.sendResultToQueue(d.TransactionID,d);
			}
		}

		protected  void run() {
			getRequest();	
			if(_queue.Count<1) return;
			DTO data=(DTO)_queue.Dequeue();
			
			ParametersHelper ph=new ParametersHelper(data.RequestArgs);
			SimpleContainer.SysLogger.DEBUG(ph.ToString());
			if(send(ph)) SimpleContainer.SysLogger.DEBUG("OK!");
			else SimpleContainer.SysLogger.DEBUG("FAIL!");
			
		}

		
		public virtual void handle(QPG.Utility.NotifyArgs arg) {
			if(arg.RequestServiceName!=ServiceName) return;
			run();
			}	
		
	

		public virtual bool Started {
			get { return _Started; }
		}

		public virtual bool Stopped {
			get {
				
				return _Stopped; 
			}
		}

		private void timer_Elapsed(object sender, System.Timers.ElapsedEventArgs e) {
			run();

		}
	}
}
